@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@ from thoth.adviser.pipeline_builder import PipelineBuilderContext
 from thoth.adviser.pipeline_config import PipelineConfig
 from thoth.adviser.resolver import Resolver
 from thoth.adviser.predictor import Predictor
+from thoth.adviser.prescription import UnitPrescription
 from thoth.adviser.state import State
 from thoth.common import RuntimeEnvironment
 from thoth.python import Project
@@ -64,6 +65,7 @@ def context(project: Project) -> Context:
         project=project,
         graph=GraphDatabase(),
         library_usage=None,
+        labels={},
         limit=100,
         count=3,
         beam=Beam(),
@@ -195,13 +197,16 @@ def builder_context(project: Project) -> PipelineBuilderContext:
     flexmock(PipelineBuilderContext)
     flexmock(GraphDatabase)
 
-    return PipelineBuilderContext(
+    yield PipelineBuilderContext(
         graph=GraphDatabase(),
         project=project,
         library_usage=None,
         decision_type=None,
         recommendation_type=RecommendationType.LATEST,
     )
+    # Clear any changes done to the should_include cache. This somehow mimics pipeline builder that
+    # always clears the cache once the pipeline is constructed.
+    UnitPrescription.SHOULD_INCLUDE_CACHE.clear()
 
 
 @pytest.fixture(scope="session", autouse=True)
