@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@ def builder_context() -> PipelineBuilderContext:
         graph=None,
         project=None,
         library_usage=None,
+        labels={},
         decision_type=DecisionType.RANDOM,
         recommendation_type=None,
     )
@@ -157,50 +158,62 @@ class TestPipelineBuilderContext(AdviserTestCase):
     def test_get_included_boots(self) -> None:
         """Test get included boots of the provided boot class."""
         builder_context = PipelineBuilderContext(decision_type=DecisionType.RANDOM)
-        assert builder_context.get_included_boots(units.boots.Boot1) == []
+        assert list(builder_context.get_included_boots(units.boots.Boot1)) == []
+        assert list(builder_context.get_included_boot_names()) == []
         unit = units.boots.Boot1()
         builder_context.add_unit(unit)
-        assert builder_context.get_included_boots(units.boots.Boot1) == [unit]
+        assert list(builder_context.get_included_boots(units.boots.Boot1)) == [unit]
+        assert list(builder_context.get_included_boot_names()) == ["Boot1"]
 
     def test_get_included_pseudonyms(self) -> None:
         """Test get included pseudonyms of the provided pseudonym class."""
         builder_context = PipelineBuilderContext(decision_type=DecisionType.RANDOM)
-        assert builder_context.get_included_pseudonyms(units.pseudonyms.Pseudonym1) == []
+        assert list(builder_context.get_included_pseudonyms(units.pseudonyms.Pseudonym1)) == []
+        assert list(builder_context.get_included_pseudonym_names()) == []
         unit = units.pseudonyms.Pseudonym1()
         builder_context.add_unit(unit)
-        assert builder_context.get_included_pseudonyms(units.pseudonyms.Pseudonym1) == [unit]
+        assert list(builder_context.get_included_pseudonyms(units.pseudonyms.Pseudonym1)) == [unit]
+        assert list(builder_context.get_included_pseudonym_names()) == ["Pseudonym1"]
 
     def test_get_included_sieves(self) -> None:
         """Get included sieves of the provided sieve class."""
         builder_context = PipelineBuilderContext(decision_type=DecisionType.RANDOM)
-        assert builder_context.get_included_sieves(units.sieves.Sieve1) == []
+        assert list(builder_context.get_included_sieves(units.sieves.Sieve1)) == []
+        assert list(builder_context.get_included_sieve_names()) == []
         unit = units.sieves.Sieve1()
         builder_context.add_unit(unit)
-        assert builder_context.get_included_sieves(units.sieves.Sieve1) == [unit]
+        assert list(builder_context.get_included_sieves(units.sieves.Sieve1)) == [unit]
+        assert list(builder_context.get_included_sieve_names()) == ["Sieve1"]
 
     def test_get_included_steps(self) -> None:
         """Get included steps of the provided step class."""
         builder_context = PipelineBuilderContext(decision_type=DecisionType.RANDOM)
-        assert builder_context.get_included_steps(units.steps.Step1) == []
+        assert list(builder_context.get_included_steps(units.steps.Step1)) == []
+        assert list(builder_context.get_included_step_names()) == []
         unit = units.steps.Step1()
         builder_context.add_unit(unit)
-        assert builder_context.get_included_steps(units.steps.Step1) == [unit]
+        assert list(builder_context.get_included_steps(units.steps.Step1)) == [unit]
+        assert list(builder_context.get_included_step_names()) == ["Step1"]
 
     def test_get_included_strides(self) -> None:
         """Get included strides of the provided stride class."""
         builder_context = PipelineBuilderContext(decision_type=DecisionType.RANDOM)
-        assert builder_context.get_included_strides(units.strides.Stride1) == []
+        assert list(builder_context.get_included_strides(units.strides.Stride1)) == []
+        assert list(builder_context.get_included_stride_names()) == []
         unit = units.strides.Stride1()
         builder_context.add_unit(unit)
-        assert builder_context.get_included_strides(units.strides.Stride1) == [unit]
+        assert list(builder_context.get_included_strides(units.strides.Stride1)) == [unit]
+        assert list(builder_context.get_included_stride_names()) == ["Stride1"]
 
     def test_get_included_wraps(self) -> None:
         """Get included wraps of the provided wrap class."""
         builder_context = PipelineBuilderContext(decision_type=DecisionType.RANDOM)
-        assert builder_context.get_included_wraps(units.wraps.Wrap1) == []
+        assert list(builder_context.get_included_wraps(units.wraps.Wrap1)) == []
+        assert list(builder_context.get_included_wrap_names()) == []
         unit = units.wraps.Wrap1()
         builder_context.add_unit(unit)
-        assert builder_context.get_included_wraps(units.wraps.Wrap1) == [unit]
+        assert list(builder_context.get_included_wraps(units.wraps.Wrap1)) == [unit]
+        assert list(builder_context.get_included_wrap_names()) == ["Wrap1"]
 
 
 class TestPipelineBuilder(AdviserTestCase):
@@ -228,31 +241,31 @@ class TestPipelineBuilder(AdviserTestCase):
         """Test building configuration."""
         # All test units do not register themselves - let's cherry-pick ones that should be present.
         # There are done 3 iterations in total during pipeline configuration creation.
-        flexmock(units.boots.Boot1).should_receive("should_include").and_return({"some_parameter": 1.0}).and_return(
-            None
-        ).and_return(None).times(3)
-        flexmock(units.pseudonyms.Pseudonym2).should_receive("should_include").and_return({}).and_return(
-            None
-        ).and_return(None).times(3)
-        flexmock(units.sieves.Sieve2).should_receive("should_include").and_return({"foo": "bar"}).and_return(
-            None
-        ).and_return(None).times(3)
-        flexmock(units.steps.Step1).should_receive("should_include").and_return({}).and_return(None).and_return(
-            None
-        ).times(3)
-        flexmock(units.strides.Stride2).should_receive("should_include").and_return({}).and_return(None).and_return(
-            None
-        ).times(3)
-        flexmock(units.strides.Stride1).should_receive("should_include").and_return(None).and_return(
+        flexmock(units.boots.Boot1).should_receive("should_include").and_yield(
+            {"some_parameter": 1.0}
+        ).and_yield().and_yield().times(3)
+        flexmock(units.pseudonyms.Pseudonym2).should_receive("should_include").and_yield(
+            {}
+        ).and_yield().and_yield().times(3)
+        flexmock(units.sieves.Sieve2).should_receive("should_include").and_yield(
+            {"foo": "bar"}
+        ).and_yield().and_yield().times(3)
+        flexmock(units.steps.Step1).should_receive("should_include").and_yield({}).and_yield().and_yield().times(3)
+        flexmock(units.strides.Stride2).should_receive("should_include").and_yield({}).and_yield().and_yield().times(3)
+        flexmock(units.strides.Stride1).should_receive("should_include").and_yield().and_yield(
             {"linus": "torvalds"}
-        ).and_return(None).times(3)
-        flexmock(units.wraps.Wrap2).should_receive("should_include").and_return({}).and_return(None).and_return(
-            None
-        ).times(3)
+        ).and_yield().times(3)
+        flexmock(units.wraps.Wrap2).should_receive("should_include").and_yield({}).and_yield().and_yield().times(3)
 
         # It is not relevant if adviser/dependency monkey is called in this case.
         pipeline = getattr(PipelineBuilder, pipeline_config_method)(
-            graph=None, project=None, library_usage=None, **kwargs
+            graph=None,
+            project=None,
+            library_usage=None,
+            labels={},
+            prescription=None,
+            cli_parameters=None,
+            **kwargs,
         )
 
         assert pipeline.to_dict() == {
@@ -295,14 +308,17 @@ class TestPipelineBuilder(AdviserTestCase):
     @use_test_units
     def test_blocked_units(self, project: Project) -> None:
         """Test preventing a pipeline unit from being added to pipeline configuration."""
-        flexmock(units.boots.Boot1).should_receive("should_include").and_return({}).and_return(None).times(2)
-        flexmock(units.steps.Step1).should_receive("should_include").and_return({}).and_return(None).times(2)
+        flexmock(units.boots.Boot1).should_receive("should_include").and_yield({}).and_yield().times(2)
+        flexmock(units.steps.Step1).should_receive("should_include").and_yield({}).and_yield().times(2)
 
         pipeline = PipelineBuilder.get_adviser_pipeline_config(
             recommendation_type=RecommendationType.LATEST,
             graph=None,
             project=project,
+            labels={},
             library_usage=None,
+            prescription=None,
+            cli_parameters=None,
         )
 
         assert len(pipeline.boots) == 1
@@ -323,7 +339,10 @@ class TestPipelineBuilder(AdviserTestCase):
                 recommendation_type=RecommendationType.LATEST,
                 graph=None,
                 project=None,
+                labels={},
                 library_usage=None,
+                prescription=None,
+                cli_parameters=None,
             )
             assert len(pipeline.boots) == 0
             assert len(pipeline.steps) == 0
@@ -416,7 +435,7 @@ class TestPipelineBuilder(AdviserTestCase):
         }
 
         yaml_path = tmp_path / "config.yaml"
-        with open(yaml_path, "w") as f:
+        with open(str(yaml_path), "w") as f:
             yaml.safe_dump(dict_, f)
 
         pipeline = PipelineBuilder.load(yaml_path)
@@ -431,7 +450,7 @@ class TestPipelineBuilder(AdviserTestCase):
         assert pipeline_dict == expected_dict_
 
         json_path = tmp_path / "config.json"
-        with open(json_path, "w") as f:
+        with open(str(json_path), "w") as f:
             json.dump(dict_, f)
 
         pipeline = PipelineBuilder.load(json_path)
