@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2020 Fridolin Pokorny
+# Copyright(C) 2020 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,12 +18,13 @@
 """A boot to check for fully specified environment."""
 
 import logging
-from typing import Optional
-from typing import Dict
 from typing import Any
+from typing import Dict
+from typing import Generator
 from typing import TYPE_CHECKING
 
 import attr
+from thoth.common import get_justification_link as jl
 
 from ..boot import Boot
 from ..exceptions import NotAcceptable
@@ -39,22 +40,23 @@ class FullySpecifiedEnvironment(Boot):
     """A boot to check for fully specified environment."""
 
     @classmethod
-    def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[str, Any]]:
+    def should_include(cls, builder_context: "PipelineBuilderContext") -> Generator[Dict[str, Any], None, None]:
         """Register self, always."""
-        if not builder_context.is_adviser_pipeline():
+        if builder_context.is_adviser_pipeline() and not builder_context.is_included(cls):
+            yield {}
             return None
 
-        if not builder_context.is_included(cls):
-            return {}
-
+        yield from ()
         return None
 
     def run(self) -> None:
         """Check for version clash in packages."""
         if not self.context.project.runtime_environment.is_fully_specified():
-            raise NotAcceptable(
-                f"Software environment supplied is not fully specified, OS name "
-                f"is {self.context.project.runtime_environment.operating_system.name!r} "
-                f"in version {self.context.project.runtime_environment.operating_system.version!r} "
-                f"using Python {self.context.project.runtime_environment.python_version!r}"
-            )
+            msg = f"Software environment supplied is not fully specified, OS name "
+            f"is {self.context.project.runtime_environment.operating_system.name!r} "
+            f"in version {self.context.project.runtime_environment.operating_system.version!r} "
+            f"using Python {self.context.project.runtime_environment.python_version!r}"
+
+            self.context.stack_info.append({"message": msg, "type": "ERROR", "link": jl("fully_specified_env")})
+
+            raise NotAcceptable(msg)
