@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2020 Fridolin Pokorny
+# Copyright(C) 2020 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,6 +36,11 @@ class Pseudonym(Unit):
     # Pseudonym is always specific to a package.
     CONFIGURATION_SCHEMA: Schema = Schema({Required("package_name"): str})
 
+    @staticmethod
+    def is_pseudonym_unit_type() -> bool:
+        """Check if this unit is of type pseudonym."""
+        return True
+
     @abc.abstractmethod
     def run(self, package_version: PackageVersion) -> Generator[Tuple[str, str, str], None, None]:
         """Run main entry-point for pseudonyms to map packages to their counterparts."""
