@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,15 +17,13 @@
 
 """A class for adviser's report - output of an adviser run."""
 
-import heapq
+import os
+import json
 import logging
-import operator
 from typing import Any
 from typing import Dict
-from typing import Generator
 from typing import List
 from typing import Optional
-from typing import Tuple
 
 import attr
 
@@ -40,18 +38,12 @@ _LOGGER = logging.getLogger(__name__)
 class Report:
     """A report stating output of an adviser run."""
 
-    count = attr.ib(type=int, kw_only=True)
+    products = attr.ib(type=List[Product], kw_only=True)
     pipeline = attr.ib(type=PipelineConfig, kw_only=True)
     resolver_iterations = attr.ib(type=int, kw_only=True, default=0)
     accepted_final_states_count = attr.ib(type=int, kw_only=True, default=0)
     discarded_final_states_count = attr.ib(type=int, kw_only=True, default=0)
     _stack_info = attr.ib(type=Optional[List[Dict[str, Any]]], kw_only=True, default=None)
-    _heapq = attr.ib(
-        type=List[Tuple[Tuple[float, int], Product]],
-        default=attr.Factory(list),
-        kw_only=True,
-    )
-    _heapq_counter = attr.ib(type=int, default=0, kw_only=True)
 
     @property
     def stack_info(self) -> Optional[List[Dict[str, Any]]]:
@@ -62,37 +54,21 @@ class Report:
         """Set stack information."""
         self._stack_info = stack_info
 
-    def add_product(self, product: Product) -> bool:
-        """Add adviser pipeline product to report."""
-        item = ((product.score, self._heapq_counter), product)
-        self._heapq_counter -= 1
-
-        if len(self._heapq) >= self.count:
-            popped = heapq.heappushpop(self._heapq, item)
-            return popped is not item
-        else:
-            heapq.heappush(self._heapq, item)
-            return True
-
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self, *, verbose: bool = False) -> Dict[str, Any]:
         """Convert pipeline report to a dict representation."""
+        stack_info: List[Dict[str, Any]] = []
+        stack_info_metadata = os.getenv("THOTH_ADVISER_METADATA")
+        if stack_info_metadata:
+            try:
+                stack_info = ((json.loads(stack_info_metadata).get("thoth.adviser") or {}).get("stack_info")) or []
+            except Exception:
+                _LOGGER.exception("Failed to load adviser metadata")
+
         return {
-            "pipeline": self.pipeline.to_dict(),
-            "products": [product.to_dict() for product in self.iter_products()],
-            "stack_info": self._stack_info,
+            "pipeline": self.pipeline.to_dict() if verbose else None,
+            "products": [product.to_dict() for product in self.products],
+            "stack_info": stack_info + (self._stack_info or []),
             "resolver_iterations": self.resolver_iterations,
             "accepted_final_states_count": self.accepted_final_states_count,
             "discarded_final_states_count": self.discarded_final_states_count,
         }
-
-    def product_count(self) -> int:
-        """Get number of products stored in the report."""
-        return len(self._heapq)
-
-    def iter_products(self) -> Generator[Product, None, None]:
-        """Iterate over products stored in this report, respect their scores."""
-        return (item[1] for item in self._heapq)
-
-    def iter_products_sorted(self, reverse: bool = True) -> Generator[Product, None, None]:
-        """Iterate over products stored in this report, respect their scores."""
-        return (item[1] for item in sorted(self._heapq, key=operator.itemgetter(0), reverse=reverse))
