@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@ def subprocess_run(
     plot: Optional[str] = None,
     *,
     with_devel: bool = True,
+    verbose: bool = False,
     user_stack_scoring: bool = True,
 ) -> int:
     """Run the given function (partial annealing method) in a subprocess and output the produced report."""
@@ -107,7 +108,7 @@ def subprocess_run(
                 else:
                     _LOGGER.info("Resolver history saved to %r", resolver_history_file)
 
-            result_dict.update(dict(error=False, error_msg=None, report=report.to_dict()))
+            result_dict.update(dict(error=False, error_msg=None, report=report.to_dict(verbose=verbose)))
         except UnresolvedDependencies as exc:
             _LOGGER.error(
                 "Resolver failed due to unsolved dependencies for packages %s; these dependencies will be "
@@ -121,9 +122,10 @@ def subprocess_run(
             return_code = 2  # If forked, do not overwrite results by parent process.
             result_dict.update(dict(error=True, error_msg=str(exc), report=exc.to_dict()))
         except Exception as exc:
-            _LOGGER.exception("Adviser raised exception: %s", str(exc))
+            error_msg = f"The resolution failed as an error was encountered: {str(exc)}"
+            _LOGGER.exception(error_msg)
             result_dict.update(
-                dict(error=True, error_msg=str(exc), report=dict(ERROR="An error occurred, see logs for more info"))
+                dict(error=True, error_msg=error_msg, report=dict(ERROR="An error occurred, see logs for more info"))
             )
             return_code = 2
 
