@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,26 +17,20 @@
 
 """Wrap units implemented in adviser."""
 
-from .no_onservation import NoObservationWrap
-from .python import NoSemanticInterpositionWrap
-from .tensorflow import TensorFlow23DictSummary
-from .tensorflow import TensorFlow23Accuracy
-from .tensorflow import IntelTensorFlowWrap
-from .tensorflow import MKLThreadsWrap
-from .tensorflow import TensorFlowMultipleProcessesGPUBug
-from .tensorflow import TensorFlowSlowKerasEmbedding
+from .libraries_io import LibrariesIOWrap
+from .pulp_release import PulpReleaseWrap
+from .pypi_release import PyPIReleaseWrap
+from .sort_justifications import SortJustificationsWrap
+from .trove_classifiers import TroveClassifiersWrap
 
 
 # Relative ordering of units is relevant, as the order specifies order
 # in which the asked to be registered - any dependencies between them
 # can be mentioned here.
 __all__ = [
-    "NoObservationWrap",
-    "NoSemanticInterpositionWrap",
-    "TensorFlow23DictSummary",
-    "TensorFlow23Accuracy",
-    "IntelTensorFlowWrap",
-    "MKLThreadsWrap",
-    "TensorFlowMultipleProcessesGPUBug",
-    "TensorFlowSlowKerasEmbedding",
+    "PyPIReleaseWrap",
+    "PulpReleaseWrap",
+    "LibrariesIOWrap",
+    "TroveClassifiersWrap",
+    "SortJustificationsWrap",  # Keep this last.
 ]
